Note: This function is deprecated. This function samples n columns of Mel-filterbank energy features as range, i.e. the order of columns is retained. Also provides some summary measures: first and last value, min and max value, and median of each column. Note: Currently, this function does not take into account chunk boundaries.

get_band_samples(mel_features, n_cols = 20, connected = TRUE, seed = 16121991)

Arguments

mel_features

List of Mel-filterbank energy features. Typically created with get_mel.

n_cols

Number of columns that should be sampled. Defaults to 20.

connected

Should the sampled columns be connected, e.g. columns 1-20, or discontinuous? Defaults to TRUE (connected).

seed

Set seed for reproducibility. Defaults to 161211991.

Value

A data frame.

Author

Dominic Schmitz

Examples

if (FALSE) band_samples <- get_band_samples(mel_features = mel_features, n_cols = 20)