This function computes Mel-based summaries for all chunks of a word (or other unit). Uses the outputs of get_mel and get_chunk_duration. The length of all summaries is padded with zeros to achieve similar lengths.

get_band_summaries(
  mel_features,
  chunk_duration,
  n_cols = 20,
  connected = TRUE,
  seed = 16121991,
  method = "spearman",
  progress = TRUE
)

Arguments

mel_features

List of Mel-filterbank energy features. Typically created with get_mel.

chunk_duration

List of chunk duration. Typically created with get_chunk_duration.

n_cols

Number of columns that should be sampled. Defaults to 20.

connected

Should the sampled columns be connected, e.g. columns 1-20, or discontinuous? Defaults to TRUE (connected).

seed

Set seed for reproducibility. Defaults to 161211991.

method

A character string indicating which correlation coefficient (or covariance) is to be computed. One of "spearman" (default), "kendall", or "pearson": can be abbreviated.

progress

Show a console progress bar. Defaults to TRUE.

Value

A list object.

Author

Dominic Schmitz

Examples

if (FALSE) band_summaries <- get_band_summaries(mel_features = my_mel_features, chunk_duration = my_chunk_durations)