This function creates lists of sound and TextGrid files. This is the initial step of the CFBS analysis.

get_corpus_files(path = NULL, sound_types = "wav")

Arguments

path

The path to the directory containing sound and TextGrid files.

sound_types

The types of sound files that should be listed. Defaults to /code"wav.

Value

A list object.

Author

Dominic Schmitz

Examples

corpus_files <- get_corpus_files(path = "data", "wav")