get_corpus_files.RdThis function creates lists of sound and TextGrid files. This is the initial step of the CFBS analysis.
get_corpus_files(path = NULL, sound_types = "wav")The path to the directory containing sound and TextGrid files.
The types of sound files that should be listed. Defaults to /code"wav.
A list object.
corpus_files <- get_corpus_files(path = "data", "wav")