get_word_sound_files.RdThis function cuts sound files by non-empty intervals on a specified tier. This tier commonly corresponds to the main_tier specified in get_word_duration.
get_word_sound_files(
sound_files,
word_durations,
extra_tier = NULL,
directory,
fileType = "auto",
from = 1,
to = Inf,
units = "samples"
)A vector of all wav files you want to include.
The durations of words or other relevant intervals. Typically identified using get_word_duration.
Optional: Include another tier. This tier will be used in unique identifier creation. Can be given by its name or by its index.
Specify the directory in which the new wav files should be saved.
Type of audio file: "wav", "mp3", or "auto".
Where to start reading in units.
Where to stop reading.
Units of from and to arguments.
A list object.
Bořil, T., & Skarnitzl, R. (2016). Tools rPraat and mPraat. In P. Sojka, A. Horák, I. Kopeček, & K. Pala (Eds.), Text, Speech, and Dialogue (pp. 367-374). Springer International Publishing.
if (FALSE) get_word_sound_files(sound_files = corpus_files[[1]], word_durations = wd_df, extra_tier = "ID", directory = "C:/Users/Project/chopped")