sphspn_to_wav.RdUsing a bash script, this function converts SPH and SPN sound files to wav files. Run this first if your sound files are not wav files.
Note: Currently, this only works on Windows. Additionally, SoX - Sound eXchange must be installed before running this function, see https://sourceforge.net/projects/sox/.
sphspn_to_wav(path)The path to the directory containing SPH and SPN sound files.
Nothing.
if (FALSE) sphspn_to_wav(path = "C:/Users/Dominic/Dropbox/HHU_2373/Compounds/CFBSFr/data")